LanguagePickerDialog class

Provides a customizable Dialog which displays all languages with optional search feature

Inheritance

Constructors

LanguagePickerDialog({Key? key, ValueChanged<Language>? onValuePicked, Widget? title, EdgeInsetsGeometry? titlePadding, EdgeInsetsGeometry contentPadding = const EdgeInsets.fromLTRB(0.0, 12.0, 0.0, 16.0), String? semanticLabel, ItemBuilder? itemBuilder, bool isDividerEnabled = false, Widget divider = const Divider(height: 0.0), bool isSearchable = false, InputDecoration? searchInputDecoration, Color? searchCursorColor, Widget? searchEmptyView, List<Language>? languages})

Properties

contentPadding → EdgeInsetsGeometry
Padding around the content.
final
divider → Widget
The (optional) horizontal separator used between title, content and actions.
final
hashCode → int
The hash code for this object.
no setterinherited
isDividerEnabled → bool
The divider is not displayed if set to false. Default is set to true.
final
isSearchable → bool
Determines if search TextField is shown or not Defaults to false
final
itemBuilder → ItemBuilder?
Callback that is called with selected item of type Language which returns a Widget to build list view item inside dialog
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
languages → List<Language>?
List of languages available in this picker.
final
onValuePicked → ValueChanged<Language>?
Callback that is called with selected Language
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchCursorColor → Color?
The optional cursorColor of search TextField
final
searchEmptyView → Widget?
The search empty view is displayed if nothing returns from search result
final
searchInputDecoration → InputDecoration?
The optional decoration of search TextField
final
semanticLabel → String?
The semantic label of the dialog used by accessibility frameworks to announce screen transitions when the dialog is opened and closed.
final
title → Widget?
The (optional) title of the dialog is displayed in a large font at the top of the dialog.
final
titlePadding → EdgeInsetsGeometry?
Padding around the title.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → SingleChoiceDialogState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited